==> mingw-w64-aws-sdk-cpp-1.9.311-1.src.tar.zst: aws-sdk-cpp-1.9.311/aws-cpp-sdk-wafv2/include/aws/wafv2/model/CaptchaConfig.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/wafv2/WAFV2_EXPORTS.h>
#include <aws/wafv2/model/ImmunityTimeProperty.h>
#include <utility>

namespace Aws
{
namespace Utils
{
namespace Json
{
  class JsonValue;
  class JsonView;
} // namespace Json
} // namespace Utils
namespace WAFV2
{
namespace Model
{

  /**
   * <p>Specifies how WAF should handle <code>CAPTCHA</code> evaluations. This is
   * available at the web ACL level and in each rule. </p><p><h3>See Also:</h3>   <a
   * href="http://docs.aws.amazon.com/goto/WebAPI/wafv2-2019-07-29/CaptchaConfig">AWS
   * API Reference</a></p>
   */
  class AWS_WAFV2_API CaptchaConfig
  {
  public:
    CaptchaConfig();
    CaptchaConfig(Aws::Utils::Json::JsonView jsonValue);
    CaptchaConfig& operator=(Aws::Utils::Json::JsonView jsonValue);
    Aws::Utils::Json::JsonValue Jsonize() const;


    /**
     * <p>Determines how long a <code>CAPTCHA</code> token remains valid after the
     * client successfully solves a <code>CAPTCHA</code> puzzle. </p>
     */
    inline const ImmunityTimeProperty& GetImmunityTimeProperty() const{ return m_immunityTimeProperty; }

    /**
     * <p>Determines how long a <code>CAPTCHA</code> token remains valid after the
     * client successfully solves a <code>CAPTCHA</code> puzzle. </p>
     */
    inline bool ImmunityTimePropertyHasBeenSet() const { return m_immunityTimePropertyHasBeenSet; }

    /**
     * <p>Determines how long a <code>CAPTCHA</code> token remains valid after the
     * client successfully solves a <code>CAPTCHA</code> puzzle. </p>
     */
    inline void SetImmunityTimeProperty(const ImmunityTimeProperty& value) { m_immunityTimePropertyHasBeenSet = true; m_immunityTimeProperty = value; }

    /**
     * <p>Determines how long a <code>CAPTCHA</code> token remains valid after the
     * client successfully solves a <code>CAPTCHA</code> puzzle. </p>
     */
    inline void SetImmunityTimeProperty(ImmunityTimeProperty&& value) { m_immunityTimePropertyHasBeenSet = true; m_immunityTimeProperty = std::move(value); }

    /**
     * <p>Determines how long a <code>CAPTCHA</code> token remains valid after the
     * client successfully solves a <code>CAPTCHA</code> puzzle. </p>
     */
    inline CaptchaConfig& WithImmunityTimeProperty(const ImmunityTimeProperty& value) { SetImmunityTimeProperty(value); return *this;}

    /**
     * <p>Determines how long a <code>CAPTCHA</code> token remains valid after the
     * client successfully solves a <code>CAPTCHA</code> puzzle. </p>
     */
    inline CaptchaConfig& WithImmunityTimeProperty(ImmunityTimeProperty&& value) { SetImmunityTimeProperty(std::move(value)); return *this;}

  private:

    ImmunityTimeProperty m_immunityTimeProperty;
    bool m_immunityTimePropertyHasBeenSet;
  };

} // namespace Model
} // namespace WAFV2
} // namespace Aws

==> mingw-w64-aws-sdk-cpp-1.9.377-1.src.tar.zst: aws-sdk-cpp-1.9.377/aws-cpp-sdk-wafv2/include/aws/wafv2/model/CaptchaConfig.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/wafv2/WAFV2_EXPORTS.h>
#include <aws/wafv2/model/ImmunityTimeProperty.h>
#include <utility>

namespace Aws
{
namespace Utils
{
namespace Json
{
  class JsonValue;
  class JsonView;
} // namespace Json
} // namespace Utils
namespace WAFV2
{
namespace Model
{

  /**
   * <p>Specifies how WAF should handle <code>CAPTCHA</code> evaluations. This is
   * available at the web ACL level and in each rule. </p><p><h3>See Also:</h3>   <a
   * href="http://docs.aws.amazon.com/goto/WebAPI/wafv2-2019-07-29/CaptchaConfig">AWS
   * API Reference</a></p>
   */
  class AWS_WAFV2_API CaptchaConfig
  {
  public:
    CaptchaConfig();
    CaptchaConfig(Aws::Utils::Json::JsonView jsonValue);
    CaptchaConfig& operator=(Aws::Utils::Json::JsonView jsonValue);
    Aws::Utils::Json::JsonValue Jsonize() const;


    /**
     * <p>Determines how long a <code>CAPTCHA</code> timestamp in the token remains
     * valid after the client successfully solves a <code>CAPTCHA</code> puzzle. </p>
     */
    inline const ImmunityTimeProperty& GetImmunityTimeProperty() const{ return m_immunityTimeProperty; }

    /**
     * <p>Determines how long a <code>CAPTCHA</code> timestamp in the token remains
     * valid after the client successfully solves a <code>CAPTCHA</code> puzzle. </p>
     */
    inline bool ImmunityTimePropertyHasBeenSet() const { return m_immunityTimePropertyHasBeenSet; }

    /**
     * <p>Determines how long a <code>CAPTCHA</code> timestamp in the token remains
     * valid after the client successfully solves a <code>CAPTCHA</code> puzzle. </p>
     */
    inline void SetImmunityTimeProperty(const ImmunityTimeProperty& value) { m_immunityTimePropertyHasBeenSet = true; m_immunityTimeProperty = value; }

    /**
     * <p>Determines how long a <code>CAPTCHA</code> timestamp in the token remains
     * valid after the client successfully solves a <code>CAPTCHA</code> puzzle. </p>
     */
    inline void SetImmunityTimeProperty(ImmunityTimeProperty&& value) { m_immunityTimePropertyHasBeenSet = true; m_immunityTimeProperty = std::move(value); }

    /**
     * <p>Determines how long a <code>CAPTCHA</code> timestamp in the token remains
     * valid after the client successfully solves a <code>CAPTCHA</code> puzzle. </p>
     */
    inline CaptchaConfig& WithImmunityTimeProperty(const ImmunityTimeProperty& value) { SetImmunityTimeProperty(value); return *this;}

    /**
     * <p>Determines how long a <code>CAPTCHA</code> timestamp in the token remains
     * valid after the client successfully solves a <code>CAPTCHA</code> puzzle. </p>
     */
    inline CaptchaConfig& WithImmunityTimeProperty(ImmunityTimeProperty&& value) { SetImmunityTimeProperty(std::move(value)); return *this;}

  private:

    ImmunityTimeProperty m_immunityTimeProperty;
    bool m_immunityTimePropertyHasBeenSet = false;
  };

} // namespace Model
} // namespace WAFV2
} // namespace Aws
